@@ -91,7 +91,7 @@ def getLocation(city):
 # Weather API Parser
 def dataformat(data):
     response = data.json()
-    keys_to_parse = ["weather", "main", "wind", "dt"]
+    keys_to_parse = ["weather", "main", "wind", "dt", "soles"]
     weather_data = {}
     for key in response:
         if key in keys_to_parse:
